Crate deno_resolver

Crate deno_resolver 

Modules

bun_lockfile_import
Translation from bun’s text lockfile (bun.lock) to a deno.lock v5 JSON string.
cache
cjs
collections
deno_json
display
It would be best to move these utilities out of this crate as this is not specific to resolution, but for the time being it’s fine for this to live here.
factory
import_map
loader
lockfile
npm
npm_lockfile_import
Translation from npm’s package-lock.json to a deno.lock v5 JSON string.
npmrc
pnpm_lockfile_import
Translation from pnpm’s pnpm-lock.yaml to a deno.lock v5 JSON string.
workspace
yarn_lockfile_import
Translation from yarn’s yarn.lock to a deno.lock v5 JSON string.

Structs

DenoIsBuiltInNodeModuleChecker
An implementation of IsBuiltInNodeModuleChecker that uses the list of built-in node_modules that are supported by Deno in the deno_node crate (ext/node).
DenoResolution
DenoResolveError
DenoResolverOptions
NodeAndNpmResolvers
NodeResolverOptions
RawDenoResolver
A resolver that takes care of resolution, taking into account loaded import map, JSX settings.

Enums

DenoResolveErrorKind

Traits

DenoResolverSys

Functions

is_react_cve_patch_enabled
Whether the React CVE source patches are enabled. Opt in by setting the DENO_PATCH_REACT_CVE environment variable to a non-empty value other than 0.
patch_react_cves
Load time source patches that neutralize two known React Server Components vulnerabilities shipped in affected react-server-dom-* builds:

Type Aliases

DefaultRawDenoResolverRc
Helper type for a RawDenoResolverRc that has the implementations used by the Deno CLI.
RawDenoResolverRc
WorkspaceResolverRc