Modules
- bun_
lockfile_ import - Translation from bun’s text lockfile (
bun.lock) to a deno.lock v5 JSON string. - cache
- cjs
- collections
- deno_
json - display
- It would be best to move these utilities out of this crate as this is not specific to resolution, but for the time being it’s fine for this to live here.
- factory
- import_
map - loader
- lockfile
- npm
- npm_
lockfile_ import - Translation from npm’s
package-lock.jsonto a deno.lock v5 JSON string. - npmrc
- pnpm_
lockfile_ import - Translation from pnpm’s
pnpm-lock.yamlto a deno.lock v5 JSON string. - workspace
- yarn_
lockfile_ import - Translation from yarn’s
yarn.lockto a deno.lock v5 JSON string.
Structs
- Deno
IsBuilt InNode Module Checker - An implementation of IsBuiltInNodeModuleChecker that uses
the list of built-in node_modules that are supported by Deno
in the
deno_nodecrate (ext/node). - Deno
Resolution - Deno
Resolve Error - Deno
Resolver Options - Node
AndNpm Resolvers - Node
Resolver Options - RawDeno
Resolver - A resolver that takes care of resolution, taking into account loaded import map, JSX settings.
Enums
Traits
Functions
- is_
react_ cve_ patch_ enabled - Whether the React CVE source patches are enabled. Opt in by setting the
DENO_PATCH_REACT_CVEenvironment variable to a non-empty value other than0. - patch_
react_ cves - Load time source patches that neutralize two known React Server Components
vulnerabilities shipped in affected
react-server-dom-*builds:
Type Aliases
- Default
RawDeno Resolver Rc - Helper type for a RawDenoResolverRc that has the implementations used by the Deno CLI.
- RawDeno
Resolver Rc - Workspace
Resolver Rc